package com.njyunzhi.ubpa.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.njyunzhi.ubpa.common.BaseController;
import com.njyunzhi.ubpa.common.Constants;
import com.njyunzhi.ubpa.common.ResponseBean;
import com.njyunzhi.ubpa.common.StringUtils;
import com.njyunzhi.ubpa.service.ITaUserService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.njyunzhi.ubpa.service.ITaOrgService;
import com.njyunzhi.ubpa.entity.TaOrg;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 企业表 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2022-05-01
 */

@Api(tags = "企业表")
@RestController
@RequestMapping("/")
public class TaOrgController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaOrgController.class);

    @Autowired
    public ITaOrgService iTaOrgService;

    @Autowired
    public ITaUserService iTaUserService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/h5/org",method= RequestMethod.GET)
    @ApiOperation(value="客户端列表", notes = "客户端列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taOrgList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                  @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                  @ApiParam("企业名称") @RequestParam(value ="orgName", required = false) String orgName) throws Exception{

        IPage<TaOrg> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaOrg> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("status", Constants.STATUS_NORMAL);
        queryWrapper.like(!StringUtils.isEmpty(orgName), "org_name", "%" + orgName + "%");
        queryWrapper.orderByAsc("org_name");
        queryWrapper.orderByDesc("create_date");

        IPage<TaOrg> result = iTaOrgService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/org",method= RequestMethod.GET)
    @ApiOperation(value="管理端列表", notes = "管理端列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean getList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                @ApiParam("企业名称") @RequestParam(value ="orgName", required = false) String orgName) throws Exception{

        IPage<TaOrg> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaOrg> queryWrapper = new QueryWrapper<>();
        queryWrapper.like(!StringUtils.isEmpty(orgName), "org_name", "%" + orgName + "%");
        queryWrapper.gt("status", Constants.STATUS_DELETE);
        queryWrapper.orderByDesc("create_date");

        IPage<TaOrg> result = iTaOrgService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param taOrg 实体对象
     * @return
     */
    @RequestMapping(value="/admin/org",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taOrgAdd(@ApiParam("保存内容") @RequestBody TaOrg taOrg) throws Exception{

        if (StringUtils.isEmpty(taOrg.getOrgName())) {
            return ResponseBean.error("企业名称不能为空");
        }

        TaOrg origin = iTaOrgService.getExistBy("org_name", taOrg.getOrgName(), false, true);
        if (origin != null) {
            return ResponseBean.error("企业名称重复");
        }

        taOrg.setOrgId(null);
        if (null == taOrg.getStatus()) {
            taOrg.setStatus(Constants.STATUS_NORMAL);
        }

        if (iTaOrgService.save(taOrg)){
            return ResponseBean.success(taOrg);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/org/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taOrgDelete(@ApiParam("对象ID") @PathVariable String id) throws Exception{

        // 首先校验是否当前物业
        // TODO

        // 如果企业有复工人员, 则不能删除
        // TODO
        // 暂不知道复工人员指什么
//        int nums = iTaUserService.countBy("org_id", id, true);
//        if (nums > 0) {
//            return ResponseBean.error("请先删除企业复工人员");
//        }

        if(iTaOrgService.removeLogicById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taOrg 实体对象
     * @return
     */
    @RequestMapping(value="/admin/org/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taOrgUpdate(@ApiParam("对象ID") @PathVariable String id,
                                        @ApiParam("更新内容") @RequestBody TaOrg taOrg) throws Exception{
        TaOrg origin = iTaOrgService.getExistBy("org_id", id, false, true);
        if (null == origin) {
            return ResponseBean.error("企业不存在");
        }

        if (StringUtils.isEmpty(taOrg.getOrgName())) {
            return ResponseBean.error("企业名称不能为空");
        }

        TaOrg sameNameOrg = iTaOrgService.getByButNot("org_name", taOrg.getOrgName(), "org_id", id, true);
        if (null != sameNameOrg) {
            return ResponseBean.error("企业名称重复");
        }

        taOrg.setOrgId(id);

        if (iTaOrgService.updateById(taOrg)){
            return ResponseBean.success(iTaOrgService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/org/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taOrgGet(@ApiParam("对象ID") @PathVariable String id) throws Exception{
        TaOrg taOrg = iTaOrgService.getById(id);
        if (taOrg.getStatus() == Constants.STATUS_DELETE) {
            return ResponseBean.error("企业不存在");
        }

        return ResponseBean.success(taOrg);
    }
}
